<?php
namespace EMS\PortalFuncionario\Geral\Repository;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;

class OperadorRepository extends Crud {

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
    }

    public function getDadosOperador(string $cdoperador) {
        try {
            $sql = <<<SQL
                SELECT
                    VM.NRVINCULOM,
                    EH.NMESCALATRABH,
                    ESH.NMRAZSOCESTRUT,
                    VM.NRORG,
                    VM.NRTIPOVINCULOM,
                    EH.PRIENTRADA,
                    EH.PRISAIDA,
                    EH.SEGENTRADA,
                    EH.SEGSAIDA
                FROM
                    GPE_VINCULOM      VM
                    JOIN GPE_VINCULOH      VH ON VH.NRORG = VM.NRORG
                                            AND VH.NRVINCULOM = VM.NRVINCULOM
                                            AND VH.DTMESCOMPETENC = (
                        SELECT
                            MAX(VHH.DTMESCOMPETENC)
                        FROM
                            GPE_VINCULOH VHH
                        WHERE
                            VHH.NRORG = VH.NRORG
                            AND VHH.NRVINCULOM = VH.NRVINCULOM
                    )
                    JOIN GPE_PESSOA        PM ON PM.NRORG = VM.NRORG
                                        AND PM.NRPESSOA = VM.NRPESSOA
                    JOIN OPERADOR          OP ON OP.NRORG = VM.NRORG
                                        AND OP.NRPARCNEGOCIO = PM.NRPARCNEGOCIO AND OP.CDOPERADOR = :P_CDOPERADOR
                    JOIN ESTRUTURAM        ESM ON ESM.NRORG = VM.NRORG
                                        AND ESM.NRESTRUTURAM = VH.NRESTRUTGEREN
                    JOIN ESTRUTURAH        ESH ON ESH.NRORG = VM.NRORG
                                        AND ESH.NRESTRUTURAM = VH.NRESTRUTGEREN
                                        AND ESH.DTMESCOMPETENC = (
                        SELECT
                            MAX(ESHH.DTMESCOMPETENC)
                        FROM
                            ESTRUTURAH ESHH
                        WHERE
                            ESHH.NRORG = ESH.NRORG
                            AND ESHH.NRESTRUTURAM = VH.NRESTRUTGEREN
                    )
                    JOIN GPE_ALTEESCALA   AE ON AE.NRORG = VM.NRORG AND AE.NRVINCULOM = VM.NRVINCULOM AND AE.DTINIESCALA = (
                        SELECT MAX(DTINIESCALA) FROM GPE_ALTEESCALA
                        WHERE GPE_ALTEESCALA.DTINIESCALA <= TRUNC(SYSDATE)
                          AND GPE_ALTEESCALA.NRVINCULOM = AE.NRVINCULOM
                          AND GPE_ALTEESCALA.NRORG = AE.NRORG
                    )
                    JOIN GPE_ESCALATRABM   EM ON EM.NRORG = VM.NRORG
                                            AND EM.NRESCALATRABM = AE.NRESCALATRABM
                    JOIN GPE_ESCALATRABH   EH ON EM.NRESCALATRABM = EH.NRESCALATRABM
                                            AND EM.NRORG = EH.NRORG
                                            AND EH.IDATIVO = 'S'
                                            AND EH.DTMESCOMPETENC = (
                        SELECT
                            MAX(DTMESCOMPETENC)
                        FROM
                            GPE_ESCALATRABH
                        WHERE
                            NRORG = EH.NRORG
                            AND NRESCALATRABM = EH.NRESCALATRABM
                            AND DTMESCOMPETENC <= SYSDATE
                            AND ( EM.DTFIMVIGENCIA >= SYSDATE
                                OR EM.DTFIMVIGENCIA IS NULL )
                    )

                    WHERE 
                        VM.DTADMISSAOVINC <= TRUNC(SYSDATE)
                        AND (VM.DTRESCISAOVINC >= TRUNC(SYSDATE) OR VM.DTRESCISAOVINC IS NULL)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);
    
            $query->execute(
                array(
                    "P_CDOPERADOR" => $cdoperador
                )
            );
            return $query->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function validaLogin(string $nrvinculom, string $nrorg) {
        try {
            $sql = <<<SQL
                SELECT
                    1
                FROM
                    GPE_VINCULOM VM
                WHERE
                    VM.NRORG = :P_NRORG
                    and VM.NRVINCULOM = :P_NRVINCULOM
                    and VM.DTADMISSAOVINC <= TRUNC(SYSDATE)
                    AND (VM.DTRESCISAOVINC >= TRUNC(SYSDATE) OR VM.DTRESCISAOVINC IS NULL)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);
    
            $query->execute(
                array(
                    "P_NRVINCULOM" => $nrvinculom,
                    "P_NRORG" => $nrorg
                )
            );
            return $query->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getClientSecret(array $params): array {
        $sql = <<<SQL
            SELECT CLIENT_SECRET
            FROM ORGANIZACAO
            WHERE NRORG = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $result = $std->fetchAll();

        return $result;
    }
}
